#define HAVE_SYS_INOTIFY_H 1

#define HAVE_INOTIFY_DIRECT_READV 0

#define HAVE_QTDBUS 1
